# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['max_ard', 'max_ard.commands', 'max_ard.io', 'max_ard.outputs']

package_data = \
{'': ['*']}

install_requires = \
['PyJWT>=2.1.0,<3.0.0',
 'Shapely>=1.7.1,<2.0.0',
 'backports.cached-property>=1.0.1,<2.0.0',
 'boto3>=1.17.73,<2.0.0',
 'click>=7.0.0,<8.0.0',
 'maxar-canvas-grid>=1.0.2,<2.0.0',
 'pydantic>=1.7.4,<2.0.0',
 'requests-oauthlib>=1.3.0,<2.0.0',
 'requests>=2.25.1,<3.0.0',
 's3fs>=0.4.2,<0.5.0']

extras_require = \
{'full': ['rasterio>=1.2.3,<2.0.0', 'Fiona>=1.8.19,<2.0.0']}

entry_points = \
{'console_scripts': ['max-ard = max_ard.commands.command:max_ard']}

setup_kwargs = {
    'name': 'max-ard',
    'version': '1.2.1',
    'description': 'ARD SDK and CLI tools',
    'long_description': '# max_ard\n\nA Python SDK and CLI for working with ARD Imagery\n\n## Introduction\n\n`max_ard` consists of a Python SDK for selecting, ordering, and working with Maxar ARD imagery and a set of CLI tools  for common tasks.\n\n## Installation\n\n`pip install max-ard --extra-index-url https://packages.ard.maxar.com/`\n\n## Prerequisites\n\nIf you are using the SDK or CLI to access data in an S3 bucket, you will need to configure your AWS credentials locally. If you install the AWS CLI tools and and can `aws s3 ls <bucket>` then you\'re set to go.\n\nTo interact with the ARD services, you also need to have ARD account credentials. Currently we store the credentials locally in a file in your home directory called `.ard-config`. It should contain:\n\n```shell\n[ard]\nuser_name = <your user name>\nuser_password = <your password>\n```\n\nThe CLI tools can be used to create this file:\n\n`max-ard login --username <your username> --password <your password`\n\n## Documentation\n\nThe full user documentation is here:\n\nhttps://ard.maxar.com/docs/sdk/\n\nThe source for these docs live in the `ard-docs` repo.\n\nAutogenerated docs are in `/docs`, generated by `pdoc3`. See `scripts/update_docs.sh` for how to update the docs.\n\nYou can run `pdoc --http : max_ard` to run a preview server on `localhost:8080`.\n\nNote that `pdoc3` is not in the Poetry dependencies because it is not compatible with Python 3.6. You will need to `pip install` it separately. \n\n## Development\n\nThis project uses Poetry for managing development. To get started using Poetry, ensure it is installed as per: https://python-poetry.org/docs/#installation.\n\nTo get started with development, create a local virtual env and install all the dependencies:\n\n```shell\npoetry config virtualenvs.in-project true --local\npoetry install --extras full\n```\n\nIf during development a new dependency is required, it can be added with the following:\n\n```shell\npoetry add <pkg_name> [--dev]\n```\n\nThis project uses Numpy style docstrings. See https://numpydoc.readthedocs.io/en/latest/format.html for reference.\n\n### Contributing\n\nThe following are steps that are to be followed during development:\n\n- All work will be through feature branches, from master, referencing the Github issue number and a short name - ie: 55-improve-error-msgs\n- All added code must covered by adequate tests that will be discovered by the current pytest configuration.\n- All code must be formatted using Black, for example: `black max_ard/session.py`. Or if you are using VSCode, &lt;ctrl>&lt;shift&lt;I> will run the configured formatter (which should be Black as per `.vscode/settings.json`).\n- All code must be formatted using isort as well, for example: `isort max_ard/session.py`.\n\n> Note: Both black and isort are in pyproject.toml, and will be installed by Poetry with the above commands.\n\n### Run Tests\n\nThere are some required env vars for running the tests, they can be found in the [.env-sample](.env-sample) file. It is up to the user to have those env vars active before running the tests. This file can be copied to a `.env` file (ARD creds need to be added), to be used with tools that support the format.\n\nTo run the tests prior to creating a PR:\n\n```shell\npoetry run ./scripts/tests\n```\n\nMany of the documentation pages are Jupyter Notebooks. To test the SDK against them, put a copy of the notebook in the `notebooks` directory. Cells tagged with "skip" are not executed.\n\n## Releases\n\nThe script for making a new release is [scripts/release](scripts/release). This can be called directly as follows:\n\n```shell\n./scripts/release patch|minor|major|prepatch|preminor|premajor|prerelease\n```\n\nThe semver argument will be passed to Poetry, see the Poetry docs for the different arguments: https://python-poetry.org/docs/cli/#version\n\nFor pre-releases, having a current version of 0.0.1, a pre-release version can be bumped by using `./scripts/release prepatch` or `./scripts/release prerelease`, which will result in `0.0.2-alpha.0`. Then to bump to `0.0.2`, run `poetry version patch`. To advance a prerelease (like `0.0.2-alpha.0` to `0.0.2-alpha.1`), use `./scripts/release prerelease`.\n\nHowever, if you want to do a pre-release for a major or minor version, use the `premajor` or `preminor` argument. Then you can use `major` or `minor` to bump to the final version. Check the Poetry docs for more details.\n\n> Note: You can run a local test install using the script [scripts/test_install](scripts/test_install). This script is used in `scripts/release`prior to trigering the full release.\n\n## Servers and Endpoints\n\nThere are two "server" endpoints:\n\n*Prod*: ard.maxar.com/api/v1 (proxies to ard.geobigdata.io)\n*Dev Main*: ard-dev.maxar.com/api/v1 (proxies to ard-dev.geobigdata.io)\n\nFeature branches can also be deployed to `ard-dev` (talk to Christy). The will have endpoints that look like:\n\n`ard-dev.maxar.com/api/v1/[endpoint group]-[branch name]/[anything else]`\n\nFor example, a `new_kml` branch would have a `select` urls:\n\n`ard-dev.maxar.com/api/v1/select-new_kml/`\n\nNote that deployed feature branches will have empty user tables - they do not share the users of the `main` dev branch.\n',
    'author': 'Marc Pfister',
    'author_email': 'marc.pfister@maxar.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://ard.maxar.com/docs/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)
